@@ -1,18 +1,18 @@
 # encoding: utf-8
-
 """
-This module defines a single template tag that will return a context object
-for your Last.fm widget. It contains a title for the widget and a ``<div>`` container. This container includes the AJAX code that retrieves the data
-from the ``lastfm`` view and generates an image for each item.
+This module defines a single template tag that will return a context object for
+your Last.fm widget. It contains a title for the widget and a ``<div>``
+container. This container includes the AJAX code that retrieves the data from
+the ``lastfm`` view and generates an image for each item.
 
 .. sourcecode:: html+django
 
     {% load lastfm_widget %}
-    
+
     {% get_lastfm_widget as lastfm_widget %}
     <h2>{{ lastfm_widget.title }}</h2>
     {{ lastfm_widget.content }}
-    
+
 The generated code will roughly look like this:
 
 .. sourcecode:: html
@@ -54,8 +54,6 @@ customize the style of the widget. This how it could look like:
     }
 
 """
-
-
 from django import template
 from django.conf import settings
 
@@ -65,13 +63,13 @@ register = template.Library()
 
 class LastfmWidgetNode(template.Node):
     """
-    This class will create a context object named ``var_name``. It will contain 
+    This class will create a context object named ``var_name``. It will contain
     the ``title`` and the ``content`` of the widget.
-    
+
     """
     def __init__(self, var_name):
         self.var_name = var_name
-        
+
     def render(self, context):
         """Load the template and render it into a context variable."""
         t = template.loader.get_template('lastfm_widget/_widget.html')
@@ -80,7 +78,7 @@ class LastfmWidgetNode(template.Node):
             'content': t.render(template.Context({},
                     autoescape=context.autoescape)),
         }
-        
+
         context[self.var_name] = lastfm_widget
         return ''
 
@@ -91,6 +89,6 @@ def get_lastfm_widget(parser, token):
     try:
         tagname, _as, var_name = token.split_contents()
     except ValueError:
-        raise template.TemplateSyntaxError('%r tag requires two arguments.' % 
+        raise template.TemplateSyntaxError('%r tag requires two arguments.' %
                 token.contents.split()[0])
     return LastfmWidgetNode(var_name)
